﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;

using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using WebApplication1.Models;
using WebApplication1.Data;
using WebApplication1.Services;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Antiforgery;
using Microsoft.AspNetCore.Mvc;

namespace WebApplication1
{
    public class Startup
    {
        private string _contentRootPath = "";
        public Startup(IHostingEnvironment env)
        {
            var builder = new ConfigurationBuilder()
               .SetBasePath(env.ContentRootPath)
               .AddJsonFile("appsettings.json", optional: true, reloadOnChange: true)
               .AddJsonFile($"appsettings.{env.EnvironmentName}.json", optional: true)
               .AddEnvironmentVariables();

            Configuration = builder.Build();

            _contentRootPath = env.ContentRootPath;
        }

        public IConfiguration Configuration { get; }

        // This method gets called by the runtime. Use this method to add services to the container.
        public void ConfigureServices(IServiceCollection services)
        {
            string connection = Configuration.GetConnectionString("NorthWndConnection");
            if (connection.Contains("%CONTENTROOTPATH%"))
            {
                connection = connection.Replace("%CONTENTROOTPATH%", _contentRootPath);
            }
            services.AddDbContext<NORTHWNDContext>(options => options.UseSqlServer(connection));
            services.AddMvc().AddSessionStateTempDataProvider()
.AddJsonOptions(x =>
            {
                x.SerializerSettings.ContractResolver = null;
            });
            services.AddMvc(options =>
            {
                options.Filters.Add(new AutoValidateAntiforgeryTokenAttribute());
            });
            //services.AddAntiforgery(options => options.HeaderName = "X-XSRF-TOKEN");          
            services.AddSession();
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IAntiforgery antiforgery,  IHostingEnvironment env)
        {
            app.UseSession();
            app.Use(next => context =>
            {
                if (
                    string.Equals(context.Request.Path.Value, "/", StringComparison.OrdinalIgnoreCase) ||
                    string.Equals(context.Request.Path.Value, "/index.html", StringComparison.OrdinalIgnoreCase))
                {
                    // We can send the request token as a JavaScript-readable cookie 
                    var tokens = antiforgery.GetAndStoreTokens(context);
                    //context.Response.Cookies.Append("XSRF-TOKEN", tokens.RequestToken,
                    //    new CookieOptions() { HttpOnly = false });
                }

                return next(context);
            });
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
                app.UseBrowserLink();
            }
            else
            {
                app.UseExceptionHandler("/Home/Error");
            }

            app.UseStaticFiles();

            app.UseMvc(routes =>
            {
                routes.MapRoute(
                    name: "default",
                    template: "{controller=Home}/{action=Index}/{id?}");
            // Controller with ID
            // To handle routes like `/api/VTRouting/1`
            //routes.MapRoute(
            //    name: "ControllerAndId",
            //    template: "api/{controller}/{id}",
            //    defaults: null,
            //    constraints: new { id = @"^\d+$" } // Only integers 
            //                                       // Controllers with Actions
            //                                       // To handle routes like `/api/VTRouting/route`
            //);
                routes.MapRoute(
    name: "ControllerAndAction",
    template: "api/{controller}/{action}"
);
              
            });
        }
    }
}
